@@ -8,6 +8,7 @@ from typing import List
 from datahub.emitter.mce_builder import make_tag_urn, make_user_urn
 from datahub.metadata.schema_classes import DatasetPropertiesClass, ContainerClass, ChangeTypeClass
 
+from metadata.ensure import ensure_type
 from metadata.entity.dataset import Dataset
 
 
@@ -17,6 +18,7 @@ logger = logging.getLogger(__name__)
 class DatasetMixin:
 
     def create_dataset(self,  dataset: Dataset, upsert=True):
+        ensure_type(dataset, Dataset)
         properties = copy.deepcopy(dataset.properties)
         properties['uri'] = dataset.uri
         dataset_properties = DatasetPropertiesClass(
